@@ -30,7 +30,7 @@
 #' }
 ef_evap <- function (ef, v, cc, dt, ca, k = 1, show = FALSE)
 {
-  ef_ev <- sysdata[[3]]
+  ef_ev <- sysdata$ev
   df <- ef_ev[ef_ev$ef == ef & ef_ev$veh == v & ef_ev$cc == cc &
                 ef_ev$dt == dt & ef_ev$canister == ca, ]
   g <- df$g*k * units::as_units("g")
