@@ -13,6 +13,7 @@
 #' @param eshotfi average daily hot-soak evaporative factor for vehicles
 #' with fuel injection and returnless fuel systems
 #' @return numeric vector of emission estimation in grams
+#' @importFrom units as_units
 #' @references Mellios G and Ntziachristos 2016. Gasoline evaporation. In:
 #' EEA, EMEP. EEA air pollutant emission inventory guidebook-2009. European
 #' Environment Agency, Copenhagen, 2009
@@ -23,6 +24,5 @@
 #' eshotfi = 1)
 #' }
 hot_soak <- function(x,carb,p,eshotc,eswarmc,eshotfi) {
-  evap <- x*(carb*(p*eshotc+(1-p)*eswarmc)+(1-carb)*eshotfi)
-  Evaporative(evap)
+  x*(carb*(p*eshotc+(1-p)*eswarmc)+(1-carb)*eshotfi)*units::as_units("g d-1")
 }
